@@ -11,12 +11,14 @@ use std::{
 	usize, fmt::{ Debug, Formatter, Result as FmtResult },
 	ops::{
 		Index, IndexMut,
-		Range, RangeFrom, RangeTo, RangeInclusive, RangeToInclusive, RangeBounds, Bound,
-		Deref, DerefMut
+		Range, RangeFrom, RangeTo, RangeInclusive, RangeToInclusive, RangeBounds, Bound
 	}
 };
 #[cfg(feature = "fast_unsafe_code")]
 use std::{ ptr, mem };
+#[cfg(feature = "deref")]
+use std::ops::{ Deref, DerefMut };
+
 
 #[derive(Default)]
 pub struct SliceQueue<T> {
@@ -300,7 +302,7 @@ impl<T> SliceQueue<T> {
 }
 impl<T: Debug> Debug for SliceQueue<T> {
 	fn fmt(&self, f: &mut Formatter) -> FmtResult {
-		Debug::fmt(&**self, f)
+		f.debug_struct("SliceQueue").field("backing", &self.backing).finish()
 	}
 }
 impl<T> From<Vec<T>> for SliceQueue<T> {
@@ -348,12 +350,14 @@ impl<T> IndexMut<usize> for SliceQueue<T> {
 	}
 }
 
+#[cfg(feature = "deref")]
 impl<T> Deref for SliceQueue<T> {
 	type Target = <Vec<T> as Deref>::Target;
 	fn deref(&self) -> &Self::Target {
 		self.backing.deref()
 	}
 }
+#[cfg(feature = "deref")]
 impl<T> DerefMut for SliceQueue<T> {
 	fn deref_mut(&mut self) -> &mut Self::Target {
 		self.backing.deref_mut()
